#!/usr/bin/env python
#Usage: $0 uni0E01 > code.txt
#or:    $0 --all

import os
import sys
import dfont

# cvt value
#NEW VALUE ***
#    "headdia":          257,    #384
#    "headstem":         258,    #120
#    "w_896":            256,    #896    =ko_kai
cvt_dict = {
    "w_1001":           71,     #1001   =
    "w_60":             260,    #60
    "w_123":            15,     #123
#
    "base":             10,     #0
    "hstem":            39,     #184
#
    "vstem":            122,    #106    =straight vstem
    "vstem_98":         143,    #98     =curve vstem
    "sarastem":         90,     #127
#
    "headdia":          127,    #344
    "headhole":         78,     #150   
    "headstem":         45,     #98    
    "headstem_plus_hole":   48,  #250
#
    "hnext_1":          111,    #469    =next spline of sho_sher
    "hnext_2":          68,     #479    =next spline of yo_ying
#
    "vheight":          156,    #1063   =normal height 
    "vheight_shoot":    140,    #1092   =overshoot height
    "vheight_plus":     203,    #1073   =normal height 
    "vheight_hi":       49,     #1208   =ko 
    "vheight_hi_kho":   47,     #1204   =kho 
    "vheight_po":       113,    #1556   =po_pla, fo_fa
    "vheight_o":        179,    #1638   =sara_o, sara_i
    "vheight_lo":       202,    #10 
    "vheight_shoot_lo": 96,     #29 
    "vheight_lu":       188,    #410    =lo_lu
#
    "vheight_below_do": 176,    #410
    "vheight_num":      209,    #905
    "vheight_sara1":    250,    #1262
#
    "head_diff":        131,    #254    =head of character: bo,po
    "beak_diff":        148,    #84     =beak of ko,tho
    "beak_diff_2":      38,     #340    =beak of ko,tho
#
    "front_25":         177,    #25     =front spacing
    "front_61":         72,     #61     =front spacing
    "front_74":         85,     #74     =front spacing
    "front_102":        42,     #102    =front spacing
    "front_125":        91,     #125    =front spacing
    "front_141":        92,     #141    =front spacing
#
    "rear_61":          72,     #61     =front spacing
    "rear_74":          85,     #74     =rear spacing
    "rear_102":         42,     #102    =front spacing
    "rear_150":         78,     #150    =rear spacing
    "rear_170":         74,     #170    =rear spacing
    "rear_203":         16,     #203    =rear spacing
#special
    "special_1":        230,    #45
    "special_2":        88,     #20
}

######### PSUEDO-CODE ##########
pseudo_code_dict = {
    #ko_kai
    "uni0E01": """
deltap1             4  24 15 24 47 24 95 24 127
srp0                23
mirp[rp0,rnd,white]  front_74 15
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  13
mirp[rp0,min,rnd,grey]  hstem  11
mdrp[rnd,grey]      9
srp0                24
mirp[rp0,rnd,white] rear_150 21
mirp[min,rnd,grey]  hstem   1
IUP[x]
SVTCA[y-axis]
mdap[rnd]           1
alignrp             13
mirp[rp0,rnd,grey]  vheight_shoot    18
ip  14
mirp[min,rnd,grey]  vstem_98  5
mdap[rnd]   14
alignrp     10
mirp[min,rnd,grey]  vstem   8
IUP[y]
""",

    #kho_khai
    "uni0E02":  """
deltap1             4   59 15 59 112 59 143 59 223
srp0                58
mirp[rp0,rnd,white]  front_61 26
mdrp[min,rnd,grey]  55
mdrp[rp0,rnd,grey]  20
mirp[min,rnd,grey]  headstem 49
srp0        26
mdrp[rp0,rnd,grey]  32
deltap1     2   32 95 32 144
mdrp[min,rnd,grey]  9
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  hstem 37
mdrp[rnd,grey]  1
srp0        59
mirp[rp0,rnd,white] rear_150 43
mirp[min,rnd,grey]  hstem 41
IUP[x]
SVTCA[y-axis]
mdap[rnd]           0
mirp[rnd,grey]      vheight 43
mirp[min,rnd,grey]  vstem 39
shp[rp2]            3
mirp[rp0,rnd,grey]  vheight 29
mirp[min,rnd,grey]  headstem 12
mdrp[rp0,rnd,grey]  16
mdrp[rp0,rnd,grey]  23
deltap1     1   23 207
mirp[min,rnd,grey]  headstem 46
mirp[rnd,grey]  headstem_plus_hole 52
IUP[y]
""",

    #kho_khuad
    "uni0E03": """
deltap1     5   62 15 62 47 62 96 62 112 62 207
deltap2     1   62 303
srp0        61
mirp[rp0,rnd,white] front_61 27
mdrp[min,rnd,grey]  58
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  headstem 52
srp0        27
mdrp[rp0,rnd,grey]  35
deltap1     2   35 95 35 144
sloop   6
ip  30 31 32 12 13 14
mdrp[min,rnd,grey]  9
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  hstem 40
mdrp[rnd,grey]  1
srp0        62
mirp[rp0,rnd,white] rear_150 46
mirp[min,rnd,grey]  hstem 44
IUP[x]
SVTCA[y-axis]
mdap[rnd]           0
mirp[min,rnd,grey]  vstem 42
shp[rp2]    22
mirp[rp0,rnd,grey]  vheight 30
alignrp     32
alignrp     45
mdrp[min,rnd,grey]  14
shp[rp2]    12
mdrp[rp0,min,rnd,grey]  31
mdrp[rp0,min,rnd,grey]  13
mdrp[rp0,rnd,white]     18
mirp[min,rnd,grey]  headstem 55
mirp[rp0,rnd,grey]  headdia 24
mirp[min,rnd,grey]  headstem 49
IUP[y]

""",

    #kho_kwai
    "uni0E04": """
deltap1     7   47 15 47 47 47 95 47 127 47 159 47 207 47 239
srp0                46
mirp[rp0,rnd,white] front_74 27
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  16
deltap1     3   16 45 16 77 16 95
mirp[min,rnd,grey]  headstem 37
mirp[rnd,grey]  headstem_plus_hole 43
srp0                27
mdrp[rp0,rnd,grey]  24
mirp[rp0,min,rnd,grey]  hstem 22
mdrp[min,rnd,grey]  10
srp0                47
mirp[rp0,rnd,white] rear_150 33
mirp[min,rnd,grey]  hstem 1
IUP[x]
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             23
MIRP[rp0,rnd,grey]  vheight_shoot  30
MIRP[rp0,min,rnd,grey]  vstem_98  5
srp1    0
ip  13
mdap[rnd]   13
MIRP[min,rnd,grey]  headstem  40
MIRP[rp0,rnd,grey]  headdia  19
deltap1     9   19 4 19 20 19 36 19 48 19 64 19 80 19 96 19 112 19 207
MIRP[min,rnd,grey]  headstem  34
IUP[y]
""",

    #kho_kon
    "uni0E05": """
deltap1         7   51 15 51 47 51 95 51 127 51 159 51 207 51 239
srp0                50
mirp[rp0,rnd,white] front_74 29
mdrp[min,rnd,grey]  10
mdrp[rp0,rnd,grey]  18
deltap1     3   18 45 18 77 18 95
mirp[min,rnd,grey]  headstem 41
mirp[rnd,grey]  headstem_plus_hole 47
srp0                29
mdrp[rp0,rnd,grey]  26
mirp[rp0,min,rnd,grey]  hstem 24
mdrp[min,rnd,grey]  12
srp0                51
mirp[rp0,rnd,white] rear_150 37
mirp[min,rnd,grey]  hstem 1
srp1        10
sloop       6
ip          32 33 34 5 6 7
IUP[x]
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             25
MIRP[rp0,rnd,grey]  vheight_shoot  32
alignrp             34
MIRP[min,rnd,grey]  vstem_98  7
mdrp[rp0,min,rnd,grey]  33
mdrp[rp0,rnd,grey]  6
MDRP[rp0,rnd,white]  15
MIRP[min,rnd,grey]  headstem  44
MIRP[rp0,rnd,grey]  headdia  21
deltap1     9   21 4 21 20 21 36 21 48 21 64 21 80 21 96 21 112 21 207
MIRP[min,rnd,grey]  headstem  38
IUP[y]
""",

    #kho_rakhang
    "uni0E06": """
deltap1     2   87 31 87 207
srp0        86
mirp[rp0,rnd,white]  front_74 38
mdrp[min,rnd,grey]  27
mdrp[rp0,rnd,grey]  32
mirp[min,rnd,grey]  headstem 65
mirp[rnd,grey]  headstem_plus_hole 71
srp0        38
mdrp[rp0,rnd,grey]  46
deltap1     2   46 95 46 127
sloop       6
ip          41 42 43 23 24 25
mdrp[min,rnd,grey]  20
mdrp[rp0,rnd,grey] 14
mirp[rp0,min,rnd,grey]  hstem 51
alignrp     3
mdrp[rp0,rnd,grey]  9
deltap1     1   9 80
mirp[min,rnd,grey]  headstem 83
mirp[rnd,grey]  headstem_plus_hole 77
srp0        87
mirp[rp0,rnd,white]  rear_150 59
mirp[min,rnd,grey]  hstem 57
srp1        51
ip          1
ip          54
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
alignrp     6
mirp[min,rnd,grey]  vstem 54
mirp[rp0,rnd,grey]  vheight 41
alignrp     43
alignrp     59
mdrp[min,rnd,grey]  25
shp[rp2]    23
mdrp[rp0,min,rnd,grey]  42
mdrp[rp0,min,rnd,grey]  24
mdrp[rp0,rnd,white]  29
mirp[min,rnd,grey]  headstem 68
mirp[rp0,rnd,grey]  headdia 35
mirp[min,rnd,grey]  headstem 62
srp0    6
mdrp[min,rnd,grey]  74
mdrp[rp0,rnd,grey]  12
deltap1     1   12 95
ip      52
mirp[min,rnd,grey]  headstem 80
srp0    52
mdrp[min,rnd,grey]  3
IUP[y]
""",

    #ngo_ngu
    "uni0E07": """
deltap1 4   35 15 35 63 35 207 35 239
srp0    34
mirp[rp0,rnd,grey]  front_25 2
mdrp[grey]  3
srp0    35
mirp[rp0,rnd,white]  rear_150 19
mirp[min,rnd,grey]  hstem 7
srp1    3
ip      1
ip      5
mdrp[rp0,rnd,grey]  13
deltap1     1   13 52
mirp[min,rnd,grey]  headstem 31
mirp[rnd,grey]  headstem_plus_hole 25
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 4
mirp[rp0,rnd,grey]  vheight 16
mdrp[min,rnd,grey]  28
mdrp[rp0,rnd,grey]  10
deltap1     2   10 64 10 80
mirp[min,rnd,grey]  headstem 22
srp2    1
ip      3
ip      2
IUP[y]
""",

    #jo_jan
    "uni0E08": """
deltap1 1   50 95
srp0    49
mirp[rp0,rnd,white] front_74 8
mdrp[rnd,grey]  27
mirp[min,rnd,grey]  headstem 46
mirp[rnd,grey]  headstem_plus_hole 40
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  hstem 2
srp0    50
mirp[rp0,rnd,white]  rear_150 34
mirp[min,rnd,grey]  hstem 19
IUP[x]
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 17
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_98 23
mdrp[rp0,rnd,white]  11
mirp[min,rnd,grey]  headstem 43
mirp[rp0,rnd,grey]  headdia 5
deltap1    8    5 0 5 32 5 48 5 64 5 80 5 96 5 112 5 207
mirp[min,rnd,grey]  headstem 37
IUP[y]
""",

    #cho_ching
    "uni0E09": """
deltap1     7   71 16 71 95 71 127 71 143 71 159 71 175 71 239
srp0    70
mirp[rp0,rnd,white] front_61 7
mdrp[rnd,grey]  24
mirp[min,rnd,grey]  headstem 56
mirp[rnd,grey]  headstem_plus_hole 50
mdrp[rp0,rnd,grey]  13
alignrp     0
mirp[min,rnd,grey]  hstem 1
srp0    71
mirp[rp0,rnd,white] rear_74 37
mirp[min,rnd,grey]  headstem 62
mirp[rp0,min,rnd,grey]  headdia 42
deltap1     8   42 0 42 16 42 32 42 48 42 64 42 80 42 96 42 112
mirp[min,rnd,grey]  headstem 68
srp0    37
mdrp[rp0,rnd,grey]  31
mirp[min,rnd,grey]  hstem 16
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
alignrp     40
mdrp[min,rnd,grey]  14
mirp[rp0,rnd,grey]  vheight_shoot  28
mirp[min,rnd,grey]  vstem_98 20
mdrp[rp0,rnd,white]  10
mirp[min,rnd,grey]  headstem 53
mirp[rp0,rnd,grey]  headdia 4
deltap1     7   4 32 4 48 4 64 4 80 4 96 4 112 4 207
mirp[min,rnd,grey]  headstem 47
srp0    40
mirp[min,rnd,grey]  headstem 59
mirp[rp0,rnd,grey]  headdia 33
deltap1     8   33 15 33 31 33 47 33 63 33 79 33 95 33 111 33 127
ip      16
ip      45
mirp[min,rnd,grey]  headstem 65
IUP[y]
""",

    #cho_chang
    "uni0E0A": """
deltap1     3   73 15 73 111 73 143
srp0    72
mirp[rp0,rnd,white]  front_61 26
mdrp[rnd,grey]  14
mdrp[min,rnd,grey]  69
mdrp[rp0,rnd,grey]  20
deltap1     2   20 176 20 192
deltap2     1   20 256
mirp[min,rnd,grey]  headstem 63
srp0    26
mdrp[rp0,rnd,grey]  32
deltap1     4   32 95 32 144 32 160 32 176
alignrp 53
mdrp[rnd,grey]  39
mdrp[min,rnd,grey]  9
mdrp[rp0,rnd,grey]  3
deltap1     1   3 208
mdrp[rnd,grey]  1
mirp[min,rnd,grey]  hstem 58
srp0    73
mirp[rp0,rnd,white]  rear_61 36
deltap1     1   36 139
mirp[min,rnd,grey]  hstem 35
srp0    73
mdrp[rp0,rnd,grey]  42
mirp[min,rnd,white]  hstem 49
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 46
shp[rp2]    3
mirp[rnd,grey]      vheight_shoot 36
mirp[rp0,rnd,grey]  vheight 29
sloop   3
ip      32 39 53
mdrp[rp0,min,rnd,grey]  12
mdrp[rp0,rnd,white]     16
deltap1     1   16 223
mirp[min,rnd,grey]      headstem 67
mirp[rp0,rnd,grey]      headdia 23
deltap1     6   23 32 23 48 23 80 23 96 23 112 23 207
mirp[min,rnd,grey]      headstem 61
IUP[y]
""",

    #so_zo
    "uni0E0B": """
deltap1     2   76 15 76 223
deltap2     1   76 303
srp0                75
mirp[rp0,rnd,white] front_61 27
mdrp[rnd,grey]      16
mdrp[min,rnd,grey]  72
mdrp[rp0,rnd,grey]  21
deltap1     3   21 160 21 176 21 192
mirp[min,rnd,grey]  headstem 66
srp0    27
mdrp[rp0,rnd,grey]  35
deltap1     5   35 95 35 144 35 160 35 176 35 192
alignrp 56
mdrp[rnd,grey]  42
mdrp[min,rnd,grey]  9
mdrp[rp0,rnd,grey]  3
deltap1     2   3 175 3 191
mdrp[rnd,grey]  1
mirp[min,rnd,grey]  hstem 61
srp0    76
mirp[rp0,rnd,white]  rear_61 39
mirp[min,rnd,grey]  hstem 38
srp0    76
mdrp[rp0,rnd,grey]  45
mirp[min,rnd,white]  hstem 52
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 49
shp[rp2]    3
mirp[min,rnd,grey]      vheight_shoot 39
mirp[rp0,rnd,grey]  vheight 30
sloop       3
ip          35 42 56
alignrp     32
mdrp[min,rnd,grey]  14
shp[rp2]    12
mdrp[rp0,min,rnd,grey]     31
mdrp[rp0,rnd,grey]     13
mdrp[rp0,rnd,white]     18
deltap1     3   18 95 18 143 18 159
mirp[min,rnd,grey]      headstem 69
mirp[rp0,rnd,grey]      headdia 24
deltap1     4   24 79 24 80 24 207 24 255
mirp[min,rnd,grey]      headstem 63
IUP[y]
""",

    #cho_choe
    "uni0E0C": """
deltap1     5   81 15 81 63 81 95 81 143 81 223 
deltap2     2   81 287 81 303
srp0    80
mirp[rp0,rnd,white] front_74 39
mdrp[min,rnd,grey]  22
mdrp[rp0,rnd,grey]  37
mirp[rp0,min,rnd,grey]  hstem 25
mdrp[rnd,grey]  23
srp0    37
mdrp[rp0,rnd,grey]  31
mirp[min,rnd,grey]  headstem 59
mirp[rnd,grey]  headstem_plus_hole 65
srp0    81
mirp[rp0,rnd,white] rear_150 53
mirp[min,rnd,grey]  hstem 51
srp1    37
ip  15
mdap[rnd]   15
mirp[min,rnd,grey]  hstem 45
srp1    51
ip  1
ip  48
srp1    31
ip  11
mdap[rnd]   11
mirp[min,rnd,grey]  headstem 77
mirp[rp0,rnd,grey]  headdia 5
deltap1     1   5 79
mirp[min,rnd,grey]  headstem 71
IUP[x]
SVTCA[y-axis]
mdap[rnd]  0
alignrp 8
alignrp 34
mirp[rnd,grey]  vheight 53
mirp[min,rnd,grey]  vstem 49
mirp[rp0,rnd,grey]  vheight_shoot 42
ip  38
mirp[min,rnd,grey]  vstem_98 19
srp0    8
mirp[min,rnd,grey] headstem 68
shp[rp2]    56
mirp[rp0,rnd,grey] headdia 15
deltap1     8   15 11 15 27 15 47 15 63 15 79 15 111 15 127 15 192
alignrp 46
alignrp 28
mirp[min,rnd,grey] headstem 74
shp[rp2]    62
mdrp[min,rnd,grey] 3
mdap[rnd]   38
alignrp 24
mirp[min,rnd,grey]  vstem 22
IUP[y]
""",

    #yo_ying
    "uni0E0D": """
deltap1     7   92 15 92 47 92 63 92 95 92 111 92 143 92 223
deltap2     2   92 287 92 303
srp0    91
mirp[rp0,rnd,white] front_74 27
mdrp[min,rnd,grey]  10
mdrp[rp0,rnd,grey]  25
mirp[rp0,min,rnd,grey]  hstem 13
mdrp[min,rnd,grey]  11
srp0    25
mdrp[rp0,rnd,grey]  19
deltap1     1   19 59
mirp[min,rnd,grey]  headstem 47
mirp[rnd,grey]  headstem_plus_hole 53
srp0    92
mirp[rp0,rnd,white] rear_150 41
mirp[min,rnd,grey]  hstem 39
srp1    25
ip  3
mdap[rnd]   3
mirp[min,rnd,grey]  hstem 33
srp2    41
ip  59
ip  76
mdap[rnd]   59
mdrp[min,rnd,grey]  70
mdrp[min,rnd,grey]  88
mdrp[rp0,rnd,grey]  65
mdrp[min,rnd,grey]  82
mdap[rnd]   76
mirp[min,rnd,grey]  w_123 75
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
alignrp     22
mirp[min,rnd,grey]  vstem 37
mirp[rnd,grey]  vheight 41
mirp[rp0,rnd,grey]  vheight_shoot 30
ip          26
mirp[min,rnd,grey]  vstem_98 7
srp0        22
mirp[min,rnd,grey] headstem 44
mirp[rp0,rnd,grey] headdia 16
deltap1     10   16 11 16 27 16 47 16 63 16 79 16 95 16 111 16 127 16 192 16 207
mirp[min,rnd,grey] headstem 50
mdap[rnd]   26
alignrp     12
mdrp[min,rnd,grey]  10
srp0        0
mdrp[rp0,rnd,white] 62
alignrp     76
mdrp[min,rnd,grey]  85
mdrp[rp0,rnd,grey]  68
mdrp[min,rnd,grey]  79
srp0    62
mdrp[rp0,rnd,grey]  56
mdrp[min,rnd,grey]  72
IUP[y]
""",

    #yo_ying
    "uni0E0D.descless": """
deltap1     7   57 15 57 47 57 63 57 95 57 111 57 143 57 223
deltap2     2   57 287 57 303
srp0    56
mirp[rp0,rnd,white] front_74 27
mdrp[min,rnd,grey]  10
mdrp[rp0,rnd,grey]  25
mirp[rp0,min,rnd,grey]  hstem 13
mdrp[min,rnd,grey]  11
srp0    25
mdrp[rp0,rnd,grey]  19
mirp[min,rnd,grey]  headstem 47
mirp[rnd,grey]  headstem_plus_hole 53
srp0    57
mirp[rp0,rnd,white] rear_150 41
mirp[min,rnd,grey]  hstem 39
srp1    25
ip  3
mdap[rnd]   3
mirp[min,rnd,grey]  hstem 33
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
alignrp     22
mirp[min,rnd,grey]  vstem 37
mirp[rnd,grey]  vheight 41
mirp[rp0,rnd,grey]  vheight_shoot 30
ip          26
mirp[min,rnd,grey]  vstem_98 7
srp0        22
mirp[min,rnd,grey] headstem 44
mirp[rp0,rnd,grey] headdia 16
deltap1     9   16 11 16 27 16 47 16 63 16 95 16 111 16 127 16 192 16 207
mirp[min,rnd,grey] headstem 50
mdap[rnd]   26
alignrp     12
mdrp[min,rnd,grey]  10
IUP[y]
""",

    #do_chada
    "uni0E0E": """
deltap1     4   81 15 81 95 81 239 81 255
deltap2     2   81 271 81 335
srp0    80
mirp[rp0,rnd,white]  front_61 41
mirp[min,rnd,grey]  headstem 66
ip  48
mirp[rnd,grey]  headstem_plus_hole 60
mdrp[rp0,rnd,grey]  34
mdrp[min,rnd,grey]  32
mirp[min,rnd,grey]  hstem 46
ip  9
mdap[rnd]   9
mdrp[min,rnd,grey]  77
srp0    81
mirp[rp0,rnd,white] rear_150 54
mirp[min,rnd,grey]  hstem 24
srp1    77
sloop   8
ip  72 14 16 17 19 3 21 1
IUP[x]
SVTCA[y-axis]
mdap[rnd]   38
mirp[rnd,grey]  vheight_lu 6
shp[rp2]    0
mirp[rp0,rnd,grey]  vheight_shoot 51
ip  47
mirp[min,rnd,grey]  vstem_98   28
mdap[rnd]   47
alignrp 33
mirp[min,rnd,grey]  vstem 31
srp0    38
mirp[min,rnd,grey]  headstem 57
mirp[rp0,rnd,grey]  headdia 44
deltap1     9   44 11 44 29 44 47 44 63 44 79 44 95 44 111 44 127 44 192
deltap2     1   44 288
mirp[min,rnd,grey]  headstem 63
srp0    5
mirp[min,rnd,grey]  headstem   69
shp[rp2]    22
mdrp[rp0,rnd,grey]  12
sloop   6
ip  72 14 16 17 19 3
mirp[min,rnd,grey]  headstem   74
IUP[y]
""",

    #to_patak
    "uni0E0F": """
deltap1     4   86 15 86 95 86 239 86 255
deltap2     2   86 271 86 335
srp0    85
mirp[rp0,rnd,white]  front_61 45
mirp[min,rnd,grey]  headstem 71
ip  52
mirp[rnd,grey]  headstem_plus_hole 65
ip  11
mdrp[rp0,rnd,grey]  38
mdrp[min,rnd,grey]  36
mirp[min,rnd,grey]  hstem 50
mdap[rnd]   11
mdrp[min,rnd,grey]  82
srp0    86
mirp[rp0,rnd,white] rear_150 59
mirp[min,rnd,grey]  hstem 28
srp1    82
sloop   14
ip  77 16 18 19 21 22 23 24 26 1 2 3 4 5
IUP[x]
SVTCA[y-axis]
mdap[rnd]   42
mirp[rnd,grey]  vheight_lu 8
shp[rp2]    3
shp[rp2]    0
mirp[rp0,rnd,grey]  vheight_shoot 55
ip  51
mirp[min,rnd,grey]  vstem_98   32
mdap[rnd]   51
alignrp 37
mirp[min,rnd,grey]  vstem 35
srp0    42
mirp[min,rnd,grey]  headstem 62
mirp[rp0,rnd,grey]  headdia 48
deltap1     9   48 11 48 29 48 47 48 63 48 79 44 95 48 111 48 127 48 192
deltap2     1   48 288
mirp[min,rnd,grey]  headstem 68
srp0    8
mirp[min,rnd,grey]  headstem   74
shp[rp2]    22
shp[rp2]    26
mdrp[rp0,rnd,grey]  14
deltap1     4   14 4 14 20 14 36 14 52
sloop   14
ip  77 16 18 19 21 22 23 24 25 1 2 3 4 5
mirp[min,rnd,grey]  headstem   79
IUP[y]
""",

    #tho_than
    "uni0E10": """
deltap1     8   126 15 126 47 126 95 126 111 126 159 126 175 126 207 126 239
srp0        125
mirp[rp0,rnd,white]  front_74 8
alignrp     21
mirp[min,rnd,grey]  headstem 55
mirp[rnd,grey]  headstem_plus_hole 49
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  hstem  2
srp0        21
mdrp[min,rnd,grey]  42
srp0        126
mirp[rp0,rnd,white] rear_170 43
alignrp     110
ip  32
ip  31
mirp[min,rnd,grey]  hstem 19
srp0        110
mdrp[rp0,rnd,grey]  104
mdrp[min,rnd,grey]  122
mdrp[min,rnd,white] 116
srp0        110
mdrp[min,rnd,grey]  98
mdrp[rp0,rnd,grey]  79
mdrp[min,rnd,grey]  64
srp1        104
sloop       12
ip  84 86 87 89 91 95 67 69 71 72 74 60
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 17
mirp[rp0,rnd,grey]  vheight_shoot   24
ip  21
mirp[min,rnd,grey]  vstem_98 39
mdrp[rp0,rnd,grey]  29
mirp[min,rnd,grey]  vstem_98 34
srp0    21
mdrp[grey]      42
mdrp[grey]      20
srp0    42
mdrp[grey]      43
srp1    21
srp2    0
ip      11
mdap[rnd]   11
mirp[min,rnd,grey]  headstem    52
mirp[rp0,rnd,grey]  headdia 5
deltap1     9   5 0 5 16 5 32 5 48 5 64 5 80 5 96 5 112 5 207
mirp[min,rnd,grey]  headstem 46
srp0    0
mdrp[rp0,rnd,white]  107
deltap1     12   107 4 107 20 107 36 107 52 107 68 107 84 107 100 107 116 107 132 107 148 107 164 107 180
mdrp[min,rnd,grey]  119
mdrp[rp0,rnd,grey]  101
mdrp[min,rnd,grey]  113
srp0    107
mdrp[rp0,rnd,grey]  66
alignrp 71
alignrp 76
mdrp[min,rnd,grey]  96
shp[rp2]    91
srp0    76
mdrp[min,rnd,grey]  58
mdrp[rp0,rnd,grey]  82
sloop   7
ip  84 86 87 89 74 93 69
mdrp[min,rnd,grey]  62
IUP[y]
""",

    #tho_than_descless
    "uni0E10.descless": """
deltap1     8   126 15 126 47 126 95 126 111 126 159 126 175 126 207 126 239
srp0        58
mirp[rp0,rnd,white]  front_74 8
alignrp     21
mirp[min,rnd,grey]  headstem 55
mirp[rnd,grey]  headstem_plus_hole 49
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  hstem  2
srp0        21
mdrp[min,rnd,grey]  42
srp0        59
mirp[rp0,rnd,white] rear_170 43
ip  32
ip  31
mirp[min,rnd,grey]  hstem 19
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 17
mirp[rp0,rnd,grey]  vheight_shoot   24
ip  21
mirp[min,rnd,grey]  vstem_98 39
mdrp[rp0,rnd,grey]  29
mirp[min,rnd,grey]  vstem_98 34
srp0    21
mdrp[grey]      42
mdrp[grey]      20
srp0    42
mdrp[grey]      43
srp1    21
srp2    0
ip      11
mdap[rnd]   11
mirp[min,rnd,grey]  headstem    52
mirp[rp0,rnd,grey]  headdia 5
deltap1     9   5 0 5 16 5 32 5 48 5 64 5 80 5 96 5 112 5 207
mirp[min,rnd,grey]  headstem 46
IUP[y]
""",

    #tho_nangmontho
    "uni0E11": """
deltap1     9   73 15 73 47 73 63 73 79 73 111 73 159 73 207 73 223 73 255
deltap2     2   73 303 73 319
srp0    72
mirp[rp0,rnd,white]  front_61 35
mdrp[min,rnd,grey]  24
mdrp[min,rnd,grey]  69
mdrp[rp0,rnd,grey]  29
deltap1     3   29 160 29 176 29 192
mirp[min,rnd,grey]  headstem 63
srp0    35
mdrp[rp0,rnd,grey]  43
sloop   6
ip  38 39 40 20 21 22
mdrp[min,rnd,grey]  17
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  hstem 48
shp[rp2]    10
srp0    73
mirp[rp0,rnd,white] rear_150 59
mirp[min,rnd,grey]  hstem 1
srp1    43
ip  53
ip  6
IUP[x]
SVTCA[y-axis]
mdap[rnd]   10
alignrp 1
mdrp[min,rnd,grey]  49
mirp[rp0,rnd,grey]  vheight  56
alignrp 38
alignrp 40
mdrp[min,rnd,grey]  4
srp0    38
mdrp[min,rnd,grey]  22
shp[rp2]    20
mdrp[rp0,min,rnd,grey]  39
mdrp[rp0,min,rnd,grey]  21
mdrp[rp0,rnd,white]  26
mirp[min,rnd,grey]  headstem    66
mirp[rp0,rnd,grey]  headdia 32
deltap1     1   32 207
mirp[min,rnd,grey]  headstem 60
IUP[y]
""",

    #tho_phuthao
    "uni0E12": """
deltap1     7   100 15 100 31 100 47 100 95 100 159 100 239 100 255
deltap2     1   100 319
SRP0                99
MIRP[rp0,rnd,white]  front_74 56
mdrp[min,rnd,grey]  23
mdrp[rp0,rnd,grey]  50
mirp[min,rnd,grey]  hstem 49
ip      29
srp0    56
mdrp[rp0,rnd,grey]  41
deltap1     2   41 95 41 192
mdrp[min,rnd,grey]  32
mirp[min,rnd,grey]  headstem 78
mirp[rp0,rnd,grey]  headdia 35
deltap1     4   35 80 35 96 35 112 35 207
mirp[min,rnd,grey]  headstem 84
srp0    100
mirp[rp0,rnd,white] rear_150 72
mirp[min,rnd,grey]  hstem 70
srp1    56
ip      14
mdap[rnd]   14
srp2    23
sloop   6
ip      59 60 61 18 19 20
mirp[rp0,min,rnd,grey]  hstem 64
mdrp[rp0,rnd,grey]  5
srp2    70
ip      67
ip      1
mirp[min,rnd,grey]  headstem 89
mirp[rp0,rnd,grey]  headdia 11
deltap1     5   11 0 11 16 11 32 11 48 11 112
mirp[min,rnd,grey]  headstem 96
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
ALIGNRP     8
ALIGNRP     49
mirp[min,rnd,grey]      vstem 68
mirp[rnd,grey]          vheight 72
MIRP[rp0,rnd,grey]      vheight_shoot  59
alignrp     61
MIRP[min,rnd,grey]      vstem  20
shp[rp2]    18
mdrp[rp0,rnd,white]     60
mdrp[rp0,rnd,grey]      19
mdrp[rp0,rnd,white]     38
mirp[min,rnd,grey]      headstem 81
mirp[rp0,rnd,grey]      headdia 32
deltap1     2   32 112 32 207
mirp[min,rnd,grey]      headstem 75
srp2        49
ip          29
srp0        8
mirp[min,rnd,grey]  headstem 87
mirp[rp0,rnd,grey]  headdia 14
deltap1     6   14 15 14 31 14 47 14 63 14 111 14 127 
ip      65
ip      3
mirp[min,rnd,grey]  headstem 93
IUP[y]
""",

    #no_nane
    "uni0E13": """
deltap1     7   76 95 76 111 76 143 76 159 76 191 76 207 76 255
deltap2     2   76 271 76 287
srp0    75
mirp[rp0,rnd,white]  front_74 25
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  23
mirp[rp0,min,rnd,grey]  hstem 11
mdrp[min,rnd,grey]  9
srp0    23
mdrp[rp0,rnd,grey]  17
deltap1     1   17 59
mirp[min,rnd,grey]  headstem 54
mirp[rnd,grey]  headstem_plus_hole 60
srp0    76
mirp[rp0,rnd,white] rear_61 42
mirp[min,rnd,grey]  headstem 66
mirp[rp0,rnd,grey]  headdia 48
deltap1     5   48 48 48 64 48 80 48 96 48 112
mirp[min,rnd,grey]  headstem 72
srp0    42
mdrp[rp0,rnd,grey]  36
mirp[min,rnd,grey]  hstem 34
srp1    23
ip      1
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 31
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
alignrp     20
alignrp     45
mdrp[min,rnd,grey]  32
mirp[rnd,grey]  vheight 36
mirp[rp0,rnd,grey]  vheight_shoot 28
ip  24
mirp[min,rnd,grey]  vstem_98 5
srp0    20
mirp[min,rnd,grey] headstem 51
shp[rp2]    63
mirp[rp0,rnd,grey] headdia 14
deltap1     9   14 11 14 31 14 47 14 63 14 79 14 95 14 111 14 127 14 192
alignrp     38
ip  34
ip  49
mirp[min,rnd,grey] headstem 57
shp[rp2]    69
mdap[rnd]   24
alignrp     10
mirp[min,rnd,grey] vstem 8
IUP[y]
""",

    #do_dek
    "uni0E14": """
deltap1     8   61 15 61 47 61 95 61 127 61 159 61 207 61 239 61 255
deltap2     3   61 287 61 319 61 351
SRP0        60
MIRP[rp0,rnd,white]   front_74 41
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  35
mirp[min,rnd,grey]  hstem 34
ip      14
srp0    41
mdrp[rp0,rnd,grey]  26
deltap1     3   26 47 26 79 26 95
mdrp[min,rnd,grey]  17
mirp[min,rnd,grey]  headstem 51
mirp[rp0,rnd,grey]  headdia 20
deltap1     7   20 32 20 48 20 68 20 80 20 96 20 112 20 207
mirp[min,rnd,grey]  headstem 57
srp0    61
mirp[rp0,rnd,white]  rear_150 47
mirp[min,rnd,grey]  hstem 1
IUP[x]
SVTCA[y-axis]
MDAP[rnd]           1
ALIGNRP             34
MIRP[rp0,rnd,grey]  vheight_shoot  44
MIRP[min,rnd,grey]  vstem_98  5
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  headstem 54
mirp[rp0,rnd,grey]  headdia 17
deltap1     7   17 32 17 48 17 64 17 80 17 96 17 112 17 207
mirp[min,rnd,grey]  headstem 48
srp2                34
ip                  14
IUP[y]
""",

    #to_tao
    "uni0E15": """
deltap1     8   65 15 65 47 65 95 65 127 65 159 65 207 65 239 65 255
deltap2     3   65 287 65 319 65 351
SRP0        64
MIRP[rp0,rnd,white]   front_74 43
mdrp[min,rnd,grey]  10
mdrp[rp0,rnd,grey]  37
mirp[min,rnd,grey]  hstem 36
ip      16
srp0    43
mdrp[rp0,rnd,grey]  28
deltap1     3   28 47 28 79 28 95
mdrp[min,rnd,grey]  19
mirp[min,rnd,grey]  headstem 55
mirp[rp0,rnd,grey]  headdia 22
deltap1     7   22 32 22 48 22 68 22 80 22 96 22 112 22 207
mirp[min,rnd,grey]  headstem 61
srp0    65
mirp[rp0,rnd,white]  rear_150 51
mirp[min,rnd,grey]  hstem 1
srp1    10
sloop   6
ip      46 47 48 5 6 7
IUP[x]
SVTCA[y-axis]
MDAP[rnd]           1
ALIGNRP             36
MIRP[rp0,rnd,grey]  vheight_shoot  46
alignrp     48
MIRP[min,rnd,grey]  vstem_98  7
shp[rp2]    5
mdrp[rp0,min,rnd,white]  47
mdrp[rp0,rnd,grey]  6
mdrp[rp0,rnd,white]  25
mirp[min,rnd,grey]  headstem 58
mirp[rp0,rnd,grey]  headdia 19
deltap1     7   19 32 19 48 19 64 19 80 19 96 19 112 19 207
mirp[min,rnd,grey]  headstem 52
srp2                36
ip                  16
IUP[y]
""",

    #to_tung
    "uni0E16": """
deltap1             7  46 15 46 47 46 95 46 127 46 207 46 239 46 255
deltap2             4  46 287 46 303 46 319 46 431
srp0                45
mirp[rp0,rnd,white]  front_74 25
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  23
mirp[rp0,min,rnd,grey]  hstem  11
mdrp[rnd,grey]      9
srp0                23
mdrp[rp0,rnd,grey]  17
deltap1     2   17 43 17 59
mirp[min,rnd,grey]  headstem 36
mirp[rnd,grey]  headstem_plus_hole 42
srp0                46
mirp[rp0,rnd,white] rear_150 31
mirp[min,rnd,grey]  hstem   1
IUP[x]
SVTCA[y-axis]
mdap[rnd]           1
alignrp             20
mirp[rp0,rnd,grey]  vheight_shoot    28
ip  24
mirp[min,rnd,grey]  vstem_98  5
mdap[rnd]   24
alignrp     10
mirp[min,rnd,grey]  vstem   8
srp0        20
mirp[min,rnd,grey]  headstem 33
mirp[rp0,rnd,grey]  headdia 14
deltap1     9   14 11 14 29 14 47 14 63 14 79 14 95 14 111 14 127 14 192 
mirp[min,rnd,grey]  headstem 39
IUP[y]
""",

    #tho_thahan
    "uni0E17": """
deltap1     6   44 31 44 63 44 159 44 207 44 239 44 255
deltap2     4   44 271 44 319 44 399 44 447
srp0        43
mirp[rp0,rnd,white]     front_61 16
mirp[min,rnd,grey]  headstem 40
mirp[rnd,grey]  headstem_plus_hole 34
mdrp[rp0,rnd,grey]  22
alignrp     9
mirp[min,rnd,grey]  hstem 10
srp0        44
mirp[rp0,rnd,white] rear_150 30
mirp[min,rnd,grey]  hstem 1
srp1        22
ip  24
ip  8
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
alignrp     9
mirp[rp0,rnd,grey]  vheight 27
alignrp     19
ip  23
mdrp[min,rnd,grey]  5
srp0        19
mirp[min,rnd,grey]  headstem 37
mirp[rp0,rnd,grey]  headdia 13
deltap1     9   13 4 13 18 13 32 13 48 13 64 13 80 13 96 13 112 13 207 
mirp[min,rnd,grey]  headstem 31
IUP[y]
""",

    #to_thong
    "uni0E18": """
deltap1     8   43 31 43 95 43 143 43 159 43 175 43 207 43 223 43 239 
srp0        42
mirp[rp0,rnd,white] front_74 5
mdrp[min,rnd,grey]  41
mdrp[rp0,rnd,grey]  3
deltap1     4   5 84 5 100 5 116 5 132
deltap1     1   3 128
alignrp     37
mirp[min,rnd,grey]  hstem 35
shp[rp2]    26
mdrp[min,rnd,grey]  1
srp0        43
mirp[rp0,rnd,white] rear_150 28
mdrp[rnd,grey]  16
mirp[min,rnd,grey]  hstem 33
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 31
shp[rp2]    2
shp[rp2]    3
mirp[rp0,rnd,grey]  vheight_shoot 8
alignrp     15
mirp[min,rnd,grey]  vstem_98 23
shp[rp2]    13
srp1        0
sloop       11
ip      38 25 41 37 26 27 3 4 35 34 28
srp0        13
mirp[min,rnd,grey]  vstem 18
srp1    8
sloop   4
ip  10 11 20 21
IUP[y]
""",

    #no_nu
    "uni0E19": """
deltap1     9   57 47 57 95 57 143 57 159 57 175 57 191 57 207 57 239 57 255 
deltap2     3   57 319 57 367 57 399 
srp0    56
mirp[rp0,rnd,white] front_61 7
mirp[min,rnd,grey]  headstem 41
mirp[rnd,grey]  headstem_plus_hole 35
mdrp[rp0,rnd,grey]  13
alignrp 0
mirp[min,rnd,grey]  hstem 1
srp0    57
mirp[rp0,rnd,white]  rear_61 23
mirp[min,rnd,grey]  headstem 47
mirp[rp0,rnd,grey]  headdia 29
deltap1     6   29 16 29 32 29 48 29 80 29 96 29 112
mirp[min,rnd,grey]  headstem 53
srp0    23
mdrp[rp0,rnd,grey]  18
deltap1     1   18 16
mirp[min,rnd,grey]  hstem 16
deltap1     2   23 11 29 0 
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
alignrp     26
mdrp[min,rnd,grey]  14
mirp[rp0,rnd,grey]  vheight 10
alignrp     18
mirp[min,rnd,grey]  headstem 38
mirp[rp0,rnd,grey]  headdia 4
deltap1     9   4 0 4 16 4 32 4 48 4 64 4 80 4 96 4 112 4 207
mirp[min,rnd,grey]  headstem 32
srp0    26
mirp[min,rnd,grey]  headstem 44
mirp[rp0,rnd,grey]  headdia 20
deltap1     7   20 11 20 31 20 47 20 63 20 95 20 111 20 127
ip  16
ip  30
mirp[min,rnd,grey]  headstem 49
IUP[y]
""",

    #bo_baimai
    "uni0E1A": """
deltap1     7   37 15 37 95 37 159 37 175 37 223 37 239 37 255
deltap2     3   37 287 37 335 37 447
srp0    36
mirp[rp0,rnd,white] front_61 9
mirp[min,rnd,grey]  headstem 33
mirp[rnd,grey]  headstem_plus_hole 27
mdrp[rp0,rnd,grey]  15
mirp[rp0,min,rnd,grey]  hstem 3
mdrp[rnd,grey]      1 
srp0    37
mirp[rp0,rnd,grey]  rear_150 21
mirp[min,rnd,grey]  hstem 19
IUP[x]
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 17
shp[rp2]    2
mirp[rp0,rnd,grey]  vheight 12
alignrp 21
mirp[min,rnd,grey]  headstem 30
mirp[rp0,rnd,grey]  headdia 6
deltap1     9   6 4 6 18 6 32 6 48 6 64 6 80 6 96 6 112 6 207 
mirp[min,rnd,grey]  headstem 24
IUP[y]
""",

    #po_pla
    "uni0E1B": """
deltap1     7   37 15 37 95 37 159 37 175 37 223 37 239 37 255
deltap2     3   37 287 37 335 37 447
srp0    36
mirp[rp0,rnd,white] front_61 9
mirp[min,rnd,grey]  headstem 33
mirp[rnd,grey]  headstem_plus_hole 27
mdrp[rp0,rnd,grey]  15
mirp[rp0,min,rnd,grey]  hstem 3
mdrp[rnd,grey]      1
srp0    37
mirp[rp0,rnd,grey]  rear_150 21
mirp[min,rnd,grey]  hstem 19
IUP[x]
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 17
shp[rp2]    2
mirp[rnd,grey]      vheight_po 21
mirp[rp0,rnd,grey]  vheight 12
mirp[min,rnd,grey]  headstem 30
mirp[rp0,rnd,grey]  headdia 6
deltap1     9   6 4 6 18 6 32 6 48 6 64 6 80 6 96 6 112 6 207
mirp[min,rnd,grey]  headstem 24
IUP[y]
""",

    #po_pung
    "uni0E1C": """
deltap1     10  38 15 38 31 38 47 38 63 38 95 38 127 38 207 38 223 38 239 38 255
deltap2     2   38 287 38 319
srp0    37
mirp[rp0,rnd,white]  front_141 6
mirp[min,rnd,grey]  hstem 18
shp[rp2]    5
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  headstem 28
mirp[rnd,grey]  headstem_plus_hole 34
srp0    38
mdrp[rp0,rnd,white] 23
mirp[min,rnd,grey]  hstem   21
shp[rp2]    1
srp1    18
ip  20
ip  3
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     5
mirp[rp0,rnd,grey]  vheight 10
alignrp 23
sloop   6
ip  19 20 21 2 3 4
mirp[min,rnd,grey]  headstem 31
mirp[rp0,rnd,grey]  headdia 16
deltap1     9   16 4 16 20 16 32 16 48 16 68 16 80 16 96 16 112 16 207 
mirp[min,rnd,grey]  headstem 25
IUP[y]
""",

    #fo_fa
    "uni0E1D": """
deltap1     10  38 15 38 31 38 47 38 63 38 95 38 127 38 207 38 223 38 239 38 255
deltap2     2   38 287 38 319
srp0    37
mirp[rp0,rnd,white]  front_141 6
mirp[min,rnd,grey]  hstem 18
shp[rp2]    5
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  headstem 28
mirp[rnd,grey]  headstem_plus_hole 34
srp0    38
mdrp[rp0,rnd,white] 23
mirp[min,rnd,grey]  hstem   21
shp[rp2]    1
srp1    18
ip  20
ip  3
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     5
mirp[rnd,grey]      vheight_po 23
mirp[rp0,rnd,grey]  vheight 10
sloop   6
ip  19 20 21 2 3 4
mirp[min,rnd,grey]  headstem 31
mirp[rp0,rnd,grey]  headdia 16
deltap1     9   16 4 16 20 16 32 16 48 16 68 16 80 16 96 16 112 16 207
mirp[min,rnd,grey]  headstem 25
IUP[y]
""",

    #po_pan
    "uni0E1E": """
deltap1     9   36 15 36 31 36 79 36 95 36 159 36 207 36 223 36 239 36 255
deltap2     1   36 271
srp0    35
mirp[rp0,rnd,white]  front_61 10
mirp[min,rnd,grey]  headstem 32
mirp[rnd,grey]  headstem_plus_hole 26
mdrp[rp0,rnd,grey]  16
alignrp     3
mirp[min,rnd,grey]  hstem 4
srp0    36
mirp[rp0,rnd,white] rear_150 22
mirp[min,rnd,grey]  hstem   20
shp[rp2]    1
srp1    16
sloop   3
ip      18 19 2
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  20
shp[rp2]    17
mirp[rp0,rnd,grey]  vheight 13
alignrp 19
alignrp 22
sloop   3
ip  2 17 20
mirp[min,rnd,grey]  headstem 29
mirp[rp0,rnd,grey]  headdia 7
deltap1     9   7 4 7 20 7 32 7 48 7 68 7 80 7 96 7 112 7 207
mirp[min,rnd,grey]  headstem 23
IUP[y]
""",

    #fo_fun
    "uni0E1F": """
deltap1     9   36 15 36 31 36 79 36 95 36 159 36 207 36 223 36 239 36 255
deltap2     1   36 271
srp0    35
mirp[rp0,rnd,white]  front_61 10
mirp[min,rnd,grey]  headstem 32
mirp[rnd,grey]  headstem_plus_hole 26
mdrp[rp0,rnd,grey]  16
alignrp     3
mirp[min,rnd,grey]  hstem 4
srp0    36
mirp[rp0,rnd,white] rear_150 22
mirp[min,rnd,grey]  hstem   20
shp[rp2]    1
srp1    16
sloop   3
ip      18 19 2
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  20
shp[rp2]    17
mirp[rnd,grey]  vheight_po 22
mirp[rp0,rnd,grey]  vheight 13
alignrp 19
sloop   3
ip  2 17 20
mirp[min,rnd,grey]  headstem 29
mirp[rp0,rnd,grey]  headdia 7
deltap1     9   7 4 7 20 7 32 7 48 7 68 7 80 7 96 7 112 7 207
mirp[min,rnd,grey]  headstem 23
IUP[y]
""",

    #po_sampao
    "uni0E20": """
deltap1     8   46 15 46 63 46 95 46 159 46 175 46 223 46 239 46 255
deltap2     2   46 271 46 335
srp0    45
mirp[rp0,rnd,white]  front_61 18
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 36
mdrp[rp0,rnd,grey]  11
ip  25
ip  8
mdrp[min,rnd,grey]  9
mirp[rp0,min,rnd,grey]  hstem 23
mdrp[rp0,rnd,grey]  10
srp0    46
mirp[rp0,rnd,white]  rear_150   31
mirp[min,rnd,grey]  hstem   1
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     15
mirp[rp0,rnd,grey]  vheight_shoot 28
ip      24
mirp[min,rnd,grey]  vstem_98   5
srp0    15
mirp[min,rnd,grey]  headstem 33
mirp[rp0,rnd,grey]  headdia 21
deltap1     9   21 11 21 29 21 47 21 63 21 79 21 95 21 111 21 127 21 192
mirp[min,rnd,grey]  headstem 39
mdap[rnd]   24
alignrp     10
mdrp[min,rnd,grey]  vstem 9
IUP[y]
""",

    #mo_ma
    "uni0E21": """
#deltap1     5   62 15 62 47 62 207 62 239 62 255
#deltap2     2   62 287 62 319
deltap1     2   62 15 62 95
srp0        61
mirp[rp0,rnd,white]  front_74 9
alignrp     20
mirp[min,rnd,grey]  headstem 58
shp[rp2]    46
mirp[rnd,grey]  headstem_plus_hole 52
shp[rp2]    40
mdrp[rp0,rnd,grey]  26
alignrp     3
mirp[min,rnd,grey]  hstem 14
srp0        62
mirp[rp0,rnd,white]  rear_150 34
mirp[min,rnd,grey]  hstem 32
srp1    26
ip  1
ip  29
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     6
mirp[min,rnd,grey]  vstem 30
mirp[rp0,rnd,grey]  vheight 23
alignrp     34
mirp[min,rnd,grey]  headstem 43
mirp[rp0,rnd,grey]  headdia 17
deltap1     9   17 4 17 20 17 32 17 48 17 68 17 80 17 96 17 112 17 207
mirp[min,rnd,grey]  headstem 37
srp0        6
mirp[min,rnd,grey]  headstem 49
mirp[rp0,rnd,grey]  headdia 12
deltap1     9   12 11 12 29 12 47 12 63 12 79 12 95 12 111 12 127 12 192
mirp[min,rnd,grey]  headstem 55
IUP[y]
""",

    #yo_yak
    "uni0E22": """
deltap1     4   52 15 52 31 52 207 52 223
deltap2     1   52  287
srp0        51
mirp[rp0,rnd,white]  front_74 10
mdrp[min,rnd,grey]  21
mdrp[rp0,rnd,grey]  16
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 48
srp0    10
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  hstem 28
srp0        52
mirp[rp0,rnd,white]  rear_150 36
srp1        10
sloop   3
ip  7 24 25
mirp[min,rnd,grey]  hstem 34
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 32
mirp[rp0,rnd,grey]  vheight 13
alignrp     36
mirp[min,rnd,grey]  headstem 45
mirp[rp0,rnd,grey]  headdia 19
deltap1     9   19 4 19 20 19 32 19 48 19 68 19 80 19 96 19 112 19 207
mirp[min,rnd,grey]  headstem 39
srp2    32
sloop   3
ip      24 7 25 
mdrp[rnd,grey]  21
IUP[y]
""",

    #ro_ruar
    "uni0E23": """
deltap1     6    49 143 49 159 49 175 49 191 49 207 49 255
srp0        48
mirp[rp0,rnd,white]  front_61 10
mdrp[min,rnd,grey]  71
srp0        49
mirp[rp0,rnd,white]  rear_170 32
ip      21
mirp[min,rnd,grey]  hstem 8
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  headstem 45
mirp[rnd,grey]  headstem_plus_hole 39
srp1    21
srp2    31
sloop   5
ip  15 16 25 26 20
IUP[x]
SVTCA[y-axis]
mdap[rnd]  0
mirp[rp0,rnd,grey]  vheight_shoot 13
alignrp     20
mirp[min,rnd,grey]  vstem_98 28
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  vstem_98 23
srp0    0
mirp[min,rnd,grey]  headstem 36
mirp[rp0,rnd,grey]  headdia 6
deltap1     9   6 11 6 29 6 47 6 63 6 79 6 95 6 111 6 127 6 192
mirp[min,rnd,grey]  headstem 42
srp1    23
srp2    6
ip      31
srp0    31
mdrp[grey]  10
srp0    10
mdrp[grey]  9
srp0    31
mdrp[grey]  32
IUP[y]
""",

    #ro_ru
    "uni0E24": """
deltap1             7  46 15 46 47 46 95 46 127 46 207 46 239 46 255
deltap2             4  46 287 46 303 46 319 46 431
srp0                45
mirp[rp0,rnd,white]  front_74 25
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  23
mirp[rp0,min,rnd,grey]  hstem  11
mdrp[rnd,grey]      9
srp0                23
mdrp[rp0,rnd,grey]  17
deltap1     2   17 43 17 59
mirp[min,rnd,grey]  headstem 36
mirp[rnd,grey]  headstem_plus_hole 42
srp0                46
mirp[rp0,rnd,white] rear_150 31
mirp[min,rnd,grey]  hstem   1
IUP[x]
SVTCA[y-axis]
mdap[rnd]           20
mirp[rnd,grey]      vheight_lu  1
mirp[rp0,rnd,grey]  vheight_shoot    28
ip  24
mirp[min,rnd,grey]  vstem_98  5
mdap[rnd]   24
alignrp     10
mirp[min,rnd,grey]  vstem   8
srp0        20
mirp[min,rnd,grey]  headstem 33
mirp[rp0,rnd,grey]  headdia 14
deltap1     9   14 11 14 29 14 47 14 63 14 79 14 95 14 111 14 127 14 192
mirp[min,rnd,grey]  headstem 39
IUP[y]
""",

    #lo_ling
    "uni0E25": """
deltap1     6   56 47 56 63 56 79 56 111 56 223 56 255
srp0    55
mirp[rp0,rnd,white] front_102 20
mirp[min,rnd,grey]  hstem 8
ip  36
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem 48
mirp[rnd,grey]  headstem_plus_hole 54
srp0    56 
mirp[rp0,rnd,white] rear_150    42
mirp[min,rnd,grey]  hstem   27
shp[rp2]    1
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     17
mirp[rp0,rnd,grey]  vheight_shoot 39
mirp[min,rnd,grey]  vstem_98 31
srp1    1
ip      24
mdap[rnd]   24
mirp[min,rnd,grey]  vstem_98 5
mdrp[grey]  27
srp0    17
mirp[min,rnd,grey]  headstem 43
mirp[rp0,rnd,grey]  headdia 11
deltap1     9   11 11 11 29 11 47 11 63 11 75 11 95 11 111 11 127 11 192
mirp[min,rnd,grey]  headstem 49
IUP[y]
""",

    #lo_lu
    "uni0E26": """
deltap1     8   46 15 46 63 46 95 46 159 46 175 46 223 46 239 46 255
deltap2     2   46 271 46 335
srp0    45
mirp[rp0,rnd,white]  front_61 18
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 36
mdrp[rp0,rnd,grey]  11
ip  25
ip  8
mdrp[min,rnd,grey]  9
mirp[rp0,min,rnd,grey]  hstem 23
mdrp[rp0,rnd,grey]  10
srp0    46
mirp[rp0,rnd,white]  rear_150   31
mirp[min,rnd,grey]  hstem   1
IUP[x]
SVTCA[y-axis]
mdap[rnd]   15
mirp[rnd,grey]      vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot 28
ip      24
mirp[min,rnd,grey]  vstem_98   5
srp0    15
mirp[min,rnd,grey]  headstem 33
mirp[rp0,rnd,grey]  headdia 21
deltap1     9   21 11 21 29 21 47 21 63 21 79 21 95 21 111 21 127 21 192
mirp[min,rnd,grey]  headstem 39
mdap[rnd]   24
alignrp     10
mdrp[min,rnd,grey]  vstem 9
IUP[y]
""",

    #wo_wan
    "uni0E27": """
deltap1     6   40 15 40 47 40 127 40 207 40 223 40 255
srp0    39
mirp[rp0,rnd,white]  front_61 16
srp0    40
mirp[rp0,rnd,white]  rear_150 23
mirp[min,rnd,grey]  hstem 8
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  headstem 36
mirp[rnd,grey]  headstem_plus_hole 30
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight_shoot 20
mirp[min,rnd,grey]  vstem_98   12
srp0    0
mirp[min,rnd,grey]  headstem 27
mirp[rp0,rnd,grey]  headdia 6
deltap1     9   6 11 6 29 6 47 6 63 6 79 6 95 6 111 6 127 6 192
mirp[min,rnd,grey]  headstem 33
IUP[y]
""",

    #so_sala
    "uni0E28": """
deltap1     6   65 95 65 127 65 159 65 175 65 207 65 255
srp0                64
mirp[rp0,rnd,white] front_74 21
mdrp[min,rnd,grey]  47
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem 55
mirp[rnd,grey]  headstem_plus_hole 61
srp0                21
mdrp[rp0,rnd,grey]  18
mirp[rp0,min,rnd,grey]  hstem 17
mdrp[min,rnd,grey]  49
srp0                65
mirp[rp0,rnd,white] rear_170 37
mdrp[rnd,grey]  31
mirp[min,rnd,grey]  hstem 1
sloop   4
ip  41 4 27 34
IUP[x]
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             17
MIRP[rp0,rnd,grey]  vheight_shoot  24
MIRP[rp0,min,rnd,grey]  vstem_98  44
srp1    0
ip  38
mdap[rnd]   38
srp2    24
sloop   5
ip  31 27 41 34 4
MIRP[min,rnd,grey]  headstem  58
MIRP[rp0,rnd,grey]  headdia  13
deltap1     9   13 4 13 20 13 36 13 48 13 64 13 80 13 96 13 112 13 207
MIRP[min,rnd,grey]  headstem  52
IUP[y]
""",

    #so_rusi
    "uni0E29": """
deltap1     7   68 15 68 95 68 159 68 175 68 223 68 239 68 255
deltap2     3   68 287 68 335 68 447
srp0    67
mirp[rp0,rnd,white] front_61 9
mirp[min,rnd,grey]  headstem 64
mirp[rnd,grey]  headstem_plus_hole 58
mdrp[rp0,rnd,grey]  15
alignrp     54
mirp[rp0,min,rnd,grey]  hstem 3
mdrp[rnd,grey]      1
srp0        68
mirp[rp0,rnd,grey]  rear_150 38
alignrp     41
ip      40
mirp[min,rnd,grey]  hstem 36
shp[rp2]    46
srp1    15
sloop   3
ip      30 23 22
IUP[x]
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 44
shp[rp2]    2
mirp[rp0,rnd,grey]  vheight 12
alignrp 38
sloop   10
ip      16 53 19 27 22 23 33 50 36 47
mirp[min,rnd,grey]  headstem 61
mirp[rp0,rnd,grey]  headdia 6
deltap1     9   6 4 6 18 6 32 6 48 6 64 6 80 6 96 6 112 6 207
mirp[min,rnd,grey]  headstem 55
IUP[y]
""",

    #so_sua
    "uni0E2A": """
deltap1     6   74 47 74 63 74 79 74 111 74 223 74 255
srp0    73
mirp[rp0,rnd,white] front_102 20
mirp[min,rnd,grey]  hstem 8
ip  34
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem 64
mirp[rnd,grey]  headstem_plus_hole 70
srp0    74
mirp[rp0,rnd,white] rear_150    51
mirp[min,rnd,grey]  hstem   52
shp[rp2]    1
sloop   6
ip  27 41 44 45 48 55
srp1    8
ip  58
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     17
mirp[rp0,rnd,grey]  vheight_shoot 38
mirp[min,rnd,grey]  vstem_98 30
srp1    1
ip      24
mdap[rnd]   24
mirp[min,rnd,grey]  vstem_98 5
ip  58
mdrp[grey]  52
srp0    17
mirp[min,rnd,grey]  headstem 61
mirp[rp0,rnd,grey]  headdia 11
deltap1     9   11 11 11 29 11 47 11 63 11 75 11 95 11 111 11 127 11 192
mirp[min,rnd,grey]  headstem 67
IUP[y]
""",

    #ho_hib
    "uni0E2B": """
deltap1     8   68 15 68 31 68 143 68 159 68 207 68 223 68 239 68 255
deltap2     3   68 271 68 303 68 319
srp0        67
mirp[rp0,rnd,white]     front_61 16
mirp[min,rnd,grey]  headstem 52
mirp[rnd,grey]  headstem_plus_hole 46
mdrp[rp0,rnd,grey]  22
alignrp     9
mirp[min,rnd,grey]  hstem 10
srp0        68
mirp[rp0,rnd,white] rear_150 42
mirp[min,rnd,grey]  hstem 1
srp1        22
ip  24
ip  8
mdrp[rp0,rnd,grey]  36
mdrp[rnd,grey]  39
mirp[min,rnd,grey]  headstem 58
mirp[rp0,rnd,grey]  headdia 30
deltap1     9   30 0 30 16 30 32 30 48 30 64 30 80 30 96 30 112 30 207
mdrp[rnd,grey]  27
mirp[min,rnd,grey]  headstem 64
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
alignrp     9
mirp[rp0,rnd,grey]  vheight 19
alignrp     33
ip  24
ip  8
mirp[min,rnd,grey]  headstem 49
shp[rp2]    61
mirp[rp0,rnd,grey]  headdia 13
deltap1     9   13 4 13 18 13 32 13 48 13 64 13 80 13 96 13 112 13 207
mirp[min,rnd,grey]  headstem 43
shp[rp2]    55
ip      27
ip      39
ip      5
IUP[y]
""",

    #lo_jula
    "uni0E2C": """
deltap1     9   63 15 63 31 63 79 63 95 63 159 63 207 63 223 63 239 63 255
deltap2     1   63 271
srp0    62
mirp[rp0,rnd,white]  front_61 10
mirp[min,rnd,grey]  headstem 47
mirp[rnd,grey]  headstem_plus_hole 41
mdrp[rp0,rnd,grey]  16
alignrp     3
mirp[min,rnd,grey]  hstem 4
srp0    63
mirp[rp0,rnd,white] rear_170 37
ip  34
ip  35
mirp[min,rnd,grey]  hstem   20
shp[rp2]    1
srp1    16
sloop   3
ip      18 19 2
mdrp[rp0,rnd,grey]  26
mirp[min,rnd,grey]  headstem 59
mirp[rnd,grey]  headstem_plus_hole 53
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  20
shp[rp2]    17
mirp[rp0,rnd,grey]  vheight 13
alignrp     23
sloop       5
ip  18 19 2 17 20
mirp[min,rnd,grey]  headstem 44
mirp[rp0,rnd,grey]  headdia 7
deltap1     9   7 4 7 20 7 32 7 48 7 68 7 80 7 96 7 112 7 207
mirp[min,rnd,grey]  headstem 38
srp0    23
mirp[min,rnd,grey]  headstem 50
mirp[rp0,rnd,grey]  headdia 29
deltap1     9   29 15 29 31 29 47 29 63 29 79 29 95 29 111 29 127 29 192 
ip  34
ip  35
mirp[min,rnd,grey]  headstem 56
IUP[y]
""",

    #aw_ang
    "uni0E2D": """
deltap1     6   52 31 52 47 52 63 52 95 52 207 52 239
srp0    51
mirp[rp0,rnd,white]  front_102 3
mirp[min,rnd,grey]  hstem 15
ip  29
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem   42
mirp[rnd,grey]  headstem_plus_hole 48
srp0     52
mirp[rp0,rnd,white]  rear_150 36
mirp[min,rnd,grey]  hstem 21
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem   19
mirp[rp0,rnd,grey]  vheight_shoot  33
ip      7
mirp[min,rnd,grey]  vstem_98   25
mdrp[rp0,rnd,grey]  4
mdap[rnd]   7
mirp[min,rnd,grey]  headstem    45
mirp[rp0,rnd,grey]  headdia 13
deltap1     7   13 32 13 48 13 64 13 80 13 96 13 112 13 207
mirp[min,rnd,grey]  headstem    39
IUP[y]
""",

    #ho_nokhuk
    "uni0E2E": """
deltap1     6   73 31 73 47 73 63 73 95 73 207 73 239
srp0    72
mirp[rp0,rnd,white]  front_102 3
mirp[min,rnd,grey]  hstem 15
ip  30
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem   63
mirp[rnd,grey]  headstem_plus_hole 69
srp0    30
mdrp[min,grey]  56
srp0     73
mirp[rp0,rnd,white]  rear_170 44
ip  39
ip  38
mirp[min,rnd,grey]  hstem 21
sloop   4
ip  50 36 41 24
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem   19
mirp[rp0,rnd,grey]  vheight_shoot  33
mirp[min,rnd,grey]  vstem_98   53
mdrp[rp0,rnd,grey]  27
deltap1     9   27 4 27 20 27 43 27 48 27 75 27 80 27 96 27 112 27 128  
sloop   4
ip  36 50 41 24
mdrp[min,rnd,grey]  47
srp2    19
ip      7
mdap[rnd]   7
mirp[min,rnd,grey]  headstem    66
mirp[rp0,rnd,grey]  headdia 13
deltap1     7   13 32 13 48 13 64 13 80 13 96 13 112 13 207
mirp[min,rnd,grey]  headstem    60
IUP[y]
""",

    #paiyannoi
    "uni0E2F": """
deltap1     2   38 15 38 31
srp0    37
mirp[rp0,rnd,white]  front_125 14
mdrp[min,rnd,grey]  25
srp0    38
mirp[rp0,rnd,white]  rear_150 36
mirp[min,rnd,grey]  hstem 1
srp1    25
sloop   6
ip  19 20 31 32 7 8
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight 35
ip  17
mdrp[min,rnd,grey]  4
mdap[rnd]   17
mdrp[min,rnd,grey]  22
mdrp[rp0,rnd,grey]  11
deltap1     6   11 36 11 48 11 84 11 116 11 132 11 212
sloop   4
ip  31 32 7 8
mdrp[min,rnd,grey]  28
IUP[y]
""",

    #sara_a
    "uni0E30": """
deltap1     8   61 47 61 63 61 79 61 127 61 159 61 175 61 191 61 223
srp0    60
mirp[rp0,rnd,white]  front_102 3
#deltap1     8   3 36 3 52 3 64 3 80 3 96 3 112 3 235 3 251
deltap1     5   3 36 3 52 3 64 3 80 3 96
alignrp 33
mirp[min,rnd,grey]  headstem 27
shp[rp2]    57
mirp[rp0,rnd,grey]  headdia 9
deltap1     6   9 47 9 63 9 79 9 95 9 111 9 127
alignrp 39
mirp[min,rnd,grey]  headstem 21
shp[rp2]    51
ip  11
ip  41
srp0    61
mirp[rp0,rnd,white] rear_170 15
alignrp 45
mdrp[min,rnd,grey]  14
shp[rp2]    44
IUP[x]
SVTCA[y-axis]
MDAP[rnd]  0
mdrp[min,rnd,grey]  11
mdrp[rp0,rnd,grey]  6
mirp[min,rnd,grey]  headstem 24
mirp[rnd,grey]  headstem_plus_hole 18
mdrp[rnd,grey]  15
srp0    0
mdrp[rp0,rnd,grey]  36
mirp[min,rnd,grey]  headstem 54
mirp[rnd,grey]  headstem_plus_hole 48
mdrp[rnd,grey]  45
mdrp[rp0,rnd,grey]  30
mdrp[min,rnd,grey]  41
IUP[y]
""",

    #sara_maihanakat
    "uni0E31": """
#mdap[rnd]   14
#mdrp[rnd,grey]  13
#mdrp[rp0,rnd,grey]  3
#mdrp[min,rnd,grey]  26
#mdrp[rp0,rnd,grey]  9
#mdrp[min,rnd,grey]  20
#IUP[x]
#SVTCA[y-axis]
#mdap[rnd]   0
#mdrp[min,rnd,grey]  11
#mdrp[rp0,rnd,grey]  6
#mdrp[min,rnd,grey]  23
#mdrp[rnd,grey]  17
#mdrp[rnd,grey]  14
#IUP[y]
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
deltap1     6   17 43 17 59 17 75 17 94 17 123 17 134
IUP[y]
""",

    #sara_aa
    "uni0E32": """
srp0    18
mirp[rp0,rnd,white]  front_61 9
srp0    19
mirp[rp0,rnd,white] rear_170 16
mirp[min,rnd,grey]  hstem 1
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 13
mirp[min,rnd,grey]  vstem_98   5
IUP[y]
""",

    #sara_am
    #uni0E33: use sara_aa with nikahit
    
    #sara_i
    "uni0E34": """
mdap[rnd]   8
mdrp[grey]   0
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
deltap1     6   8 43 8 59 8 75 8 94 8 123 8 134
IUP[y]
""",

    #sara_ii
    "uni0E35": """
mdap[rnd]   11
mdrp[grey]   0
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
deltap1     6   15 43 15 59 15 75 15 94 15 123 15 134
IUP[y]
""",

    #sara_ue
    "uni0E36": """
mdap[rnd]   20
mdrp[grey]   0
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
deltap1     6   20 43 20 59 20 75 20 94 20 123 20 134
deltap1     6   28 43 28 59 28 75 28 94 28 123 28 134
IUP[y]
""",

    #sara_uee
    "uni0E37": """
mdap[rnd]   13
mdrp[grey]   0
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
deltap1     6   18 43 18 59 18 75 18 94 18 123 18 134
IUP[y]
""",

    #sara_u
    "uni0E38": """
deltap1     3   0 5 0 22 0 38
deltap1     3   14 5 14 22 14 38
IUP[x]
SVTCA[y-axis]
deltap1     12  0 2 0 18 0 34 0 50 0 66 0 82 0 98 0 114 0 132 0 148 0 166 0 182
deltap1     12  14 2 14 18 14 34 14 50 14 66 14 82 14 98 14 114 14 132 14 148 14 166 14 182
IUP[y]
""",

    #sara_uu
    "uni0E39": """
deltap1     3   0 5 0 22 0 38
deltap1     3   24 5 24 22 24 38
IUP[x]
SVTCA[y-axis]
deltap1     12  0 2 0 18 0 34 0 50 0 66 0 82 0 98 0 114 0 132 0 148 0 166 0 182
deltap1     12  24 2 24 18 24 34 24 50 24 66 24 82 24 98 24 114 24 132 24 148 24 166 24 182
IUP[y]
""",

    #pinthu
    "uni0E3A": """
deltap1     3   0 5 0 22 0 38
IUP[x]
SVTCA[y-axis]
deltap1     12  0 2 0 18 0 34 0 50 0 66 0 82 0 98 0 114 0 132 0 148 0 166 0 182
IUP[y]
""",

    #thai_baht
    "uni0E3F": """
srp0    51
mdrp[rp0,rnd,grey]  5
mdrp[min,rnd,grey]  3
shp[rp2]    7
mdrp[min,rnd,grey]  29
shp[rp2]    42
mdrp[rp0,rnd,grey]  27
sloop       3
alignrp     1 40 9
mdrp[rp0,min,rnd,grey]  39
sloop       3
alignrp     26 50 11
srp0        5
mdrp[rp0,rnd,grey]  22
mdrp[min,rnd,grey]  35
mdrp[rp0,rnd,grey]  16
mdrp[min,rnd,grey]  47
srp0        22
mdrp[rnd,white]     52
IUP[x]
SVTCA[y-axis]
mdap[rnd]   3
alignrp     25
mdrp[rnd,grey]  1
mdrp[min,rnd,grey]  31
shp[rp2]    30
shp[rp2]    4
mdrp[rp0,rnd,grey]  43
mdrp[min,rnd,grey]  28
ip  19
shp[rp2]    38
srp0        3
mdrp[rp0,rnd,grey]  8
mdrp[rnd,grey]  10
mdrp[min,rnd,grey]  42
shp[rp2]    50
shp[rp2]    7
IUP[y]
""",

    #sara_e
    "uni0E40": """
srp0    27
mirp[rp0,rnd,white]  rear_74 11
mirp[min,rnd,grey]  headstem 17
mirp[rnd,grey]  headstem_plus_hole 23
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  hstem 5
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mirp[rnd,grey]  vheight 4
mirp[min,rnd,grey]  headstem 14
mirp[rp0,rnd,grey]  headdia 8
deltap1     9   8 11 8 29 8 47 8 63 8 75 8 95 8 111 8 127 8 192 
mirp[min,rnd,grey]  headstem 20
IUP[y]
""",

    #sara_ae
    #use sara_a reference: uni0E40

    #sara_o
    "uni0E42": """
srp0    46
mirp[rp0,rnd,white]  front_61 5
mdrp[min,rnd,grey]  24
srp0    47
mirp[rp0,rnd,white] rear_74 31
mirp[min,rnd,grey]  headstem 37
mirp[rnd,grey]  headstem_plus_hole 43
mdrp[rp0,rnd,grey]  3
ip  14
ip  15
mirp[min,rnd,grey]  hstem   25
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  headstem   34
mirp[rp0,rnd,grey]  headdia 28
deltap1     9   28 11 28 29 28 47 28 63 28 75 28 95 28 111 28 127 28 192 
mirp[min,rnd,grey]  headstem   40
mdap[rnd]   7
mirp[min,rnd,grey]  vstem 22
ip  14
ip  15
mdrp[rp0,rnd,grey]  12
mirp[min,rnd,grey]  vstem_98 17
srp1    22
srp2    0
ip      5
mdap[rnd]   5
mdrp[grey]  4
mdrp[rp0,grey]  24
mdrp[grey]  25
IUP[y]
""",

    #sara_ai_maimoun
    "uni0E43": """
srp0    67
mirp[rp0,rnd,white] front_25 40
mdrp[min,rnd,grey]  10
srp0    68
mirp[rp0,rnd,white] rear_74 52
mirp[min,rnd,grey]  headstem 58
mirp[rnd,grey]  headstem_plus_hole 64
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  hstem 46
srp2    10
sloop   6
ip      28 22 25 24 16 34
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  headstem 55
mirp[rp0,rnd,grey]  headdia 49
deltap1     9   49 11 49 29 49 47 49 63 49 75 49 95 49 111 49 127 49 192 
mirp[min,rnd,grey]  headstem 61
mdap[rnd]   43
mdrp[min,rnd,grey]  7
mdrp[rp0,rnd,grey]  37
mdrp[min,rnd,grey]  13
srp1    7
sloop   4
ip      31 19 24 25
IUP[y]
""",

    #sara_ai_malai
    "uni0E44": """
srp0    60
alignrp 21
mdrp[rnd,grey]  22
srp0    61
mirp[rp0,rnd,white] rear_74 45
mirp[min,rnd,grey]  headstem 51
mirp[rnd,grey]  headstem_plus_hole 57
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  hstem 39
srp2    21
sloop   4
ip  18 26 33 11
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  headstem 48
mirp[rp0,rnd,grey]  headdia 42
deltap1     9   42 11 42 29 42 47 42 63 42 75 42 95 42 111 42 127 42 192 
mirp[min,rnd,grey]  headstem 54
mdap[rnd]   36
mdrp[rnd,grey]  22
mdrp[min,rnd,grey]  7
mdrp[rp0,rnd,grey]  14
mdrp[min,rnd,grey]  29
IUP[y]
""",

    #lakkhangyao
    "uni0E45": """
srp0    18
mirp[rp0,rnd,grey]  front_102 9
srp0    19
mirp[rp0,rnd,white] rear_203 16
mirp[min,rnd,grey]  hstem 1
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   18
mirp[rnd,grey]  vheight_lu  1
mirp[rp0,rnd,grey]  vheight_shoot 13
mirp[min,rnd,grey]  vstem_98   5
IUP[y]
""",

    #maiyamok
    "uni0E46": """
deltap1     4   40 47 40 79 40 175 40 207
srp0    39
mirp[rp0,rnd,white]  front_102 19
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  headstem 30
mirp[rnd,grey]  headstem_plus_hole 36
srp0    40
mirp[rp0,rnd,white] rear_170 25
mirp[min,rnd,grey]  hstem 1
srp1    8
sloop   6
ip  21 6 22 5 23 4
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   39
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight 21
alignrp 23
mirp[min,rnd,grey]  vstem   6
shp[rp2]    4
mdrp[rp0,rnd,grey]  22
mirp[min,rnd,grey]  vstem_98   5
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem    33
mirp[rp0,rnd,grey]  headdia 16
mirp[min,rnd,grey]  headstem    27
IUP[y]
""",

    #maitaikhu
    "uni0E47": """
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
deltap1     6   51 43 51 59 51 75 51 94 51 123 51 134
IUP[y]
""",

    #maiek
    "uni0E48": """
srp0    0
mirp[min,rnd,grey]  sarastem 2
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  headdia_tiny 2
IUP[y]
""",

    #maiek
    "uni0E48.low": """
mdap[rnd]   6
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
#deltap1     6   17 43 17 59 17 75 17 94 17 123 17 134
IUP[y]
""",

    #maitho
    "uni0E49": """
MDAP[rnd]   1
mdrp[rp0,rnd,grey]  8
mdrp[min,rnd,grey]  5
mirp[min,rnd,grey]  headstem_wan 34
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem_wan 27
mdrp[rp0,rnd,grey]  17
mdrp[rp0,rnd,grey]  21
mdrp[min,rnd,grey]  22
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
mirp[min,rnd,grey]  headstem_tiny 17
shp[rp2]    2
mdrp[rp0,rnd,grey]  5
mirp[min,rnd,grey]  headstem_wan 25
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  headstem_wan 31
srp0    1
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  vstem 22
IUP[y]
""",

    #maitho
    "uni0E49.low": """
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
deltap1     6   26 43 26 59 26 75 26 94 26 123 26 134
IUP[y]
""",

    #maitri
    "uni0E4A": """
mdap[rnd]   1
mdrp[rp0,rnd,grey]  11
mirp[rp0,min,rnd,grey]  vstem_tiny 23
mdrp[min,rnd,grey]  47
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  headstem_wan 41
srp0    1
mdrp[rp0,rnd,grey]  2
mdrp[min,rnd,grey]  33
mdrp[rp0,rnd,grey]  5
mirp[min,rnd,grey]  vstem_tiny 31
srp0    33
mdrp[rp0,rnd,grey]  35
mdrp[min,rnd,grey]  36
srp1   11
srp2   1
sloop   6
ip  26 9 27 8 28 7
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
mdrp[rp0,rnd,grey]  20
mirp[min,rnd,grey]  headstem_wan 38
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem_wan 44
mdrp[rp0,rnd,grey]   8
mirp[rp0,min,rnd,grey]  headstem_tiny 27
mdrp[rp0,rnd,grey]  26
alignrp 28
mirp[min,rnd,grey]  headstem_tiny 9
shp[rp2]    7
srp0    1
mdrp[rp0,min,rnd,grey]  2
mdrp[rp0,rnd,grey]  33
mdrp[rp0,rnd,grey]  35
mdrp[min,rnd,grey]  36
IUP[y]
""",

    #maitri
    "uni0E4A.low": """
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
deltap1     6   49 43 49 59 49 75 49 94 49 123 49 134
IUP[y]
""",

    #maichattawa
    "uni0E4B": """
srp0    0
alignrp 8
mdrp[min,rnd,grey]  10
mirp[rp0,rnd,grey]  sarastem 6
alignrp 2
mdrp[min,rnd,grey]  4
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  10
alignrp 2
mirp[rp0,rnd,grey]  sarastem 8
alignrp 4
mdrp[min,rnd,grey]  6
IUP[y]
""",

    #maichattawa
    "uni0E4B.low": """
mdap[rnd]   7
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
IUP[y]
""",

    #thanthakhat
    "uni0E4C": """
srp0    0
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  29
mdrp[rp0,rnd,grey]  17
mdrp[min,rnd,grey]  23
mdrp[rp0,rnd,grey]  15
mdrp[rp0,rnd,grey]  11
mdrp[min,rnd,grey]  10
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  20
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  26
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  11
IUP[y]
""",

    #thanthakhat
    "uni0E4C.low": """
mdap[rnd]   18
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
deltap1     6   21 43 21 59 21 75 21 94 21 123 21 134
IUP[y]
""",

    #nikhahit
    "uni0E4D": """
mdap[rnd]   9
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
deltap1     6   12 43 12 59 12 75 12 94 12 123 12 134
IUP[y]
""",

    #nikhahit
    "uni0E4D.high": """
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  9
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  21
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  18
IUP[y]
""",

    #yamakkan
    "uni0E4E": """
mdap[rnd]   3
IUP[x]
SVTCA[y-axis]
deltap1     6   0 43 0 59 0 75 0 94 0 123 0 134
IUP[y]
""",

    #fongman
    "uni0E4F": """
SRP0    56
mdrp[rp0,min,rnd,grey]  5
mdrp[min,rnd,grey]  29
mdrp[rp0,rnd,grey]  35
mdrp[min,rnd,grey]  53
mdrp[rp0,rnd,grey]  41
mdrp[min,rnd,grey]  47
mdrp[rp0,rnd,grey]  15
mdrp[min,rnd,grey]  23
mdrp[rnd,white]  57
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   56
mirp[rp0,rnd,grey]  vheight_lo 0
mdrp[min,rnd,grey]  20
mdrp[rp0,rnd,grey]  32
mdrp[min,rnd,grey]  44
mdrp[rp0,rnd,grey]  38
mdrp[min,rnd,grey]  50
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  26
IUP[y]
""",

    #thaidigit_zero
    "uni0E50": """
SRP0    24
mirp[rp0,min,rnd,grey]  headhole    3
mirp[min,rnd,grey]  hstem   21
mirp[rp0,rnd,grey]  w_956    9
mirp[min,rnd,grey]  hstem   15
mdrp[rnd,white]  25
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   24
mirp[rnd,grey]  vheight_lo  0
mirp[rp0,rnd,grey]  vheight_num 6
mirp[min,rnd,grey]  vstem_98 18
srp0    0
mirp[min,rnd,grey]  vstem_98 12
IUP[y]
""",

    #thaidigit_one
    "uni0E51": """
SRP0    48
mirp[rp0,min,rnd,grey]  headhole    3
mirp[min,rnd,grey]  hstem   22
mdrp[rp0,min,rnd,grey]  27
mdrp[rnd,grey]  25
mirp[min,rnd,grey]  headstem 45
mdrp[rp0,min,rnd,grey]  33
mirp[min,rnd,grey]  headstem 39
mdrp[rp0,min,rnd,grey]  16
mirp[rp0,min,rnd,grey]  hstem 9
mdrp[rnd,white]  49
mdrp[rp0,rnd,grey]  12
mdrp[rnd,grey]  13
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   48
mirp[rp0,rnd,grey]  vheight_num 6
mirp[min,rnd,grey]  vstem_98 19
srp0    48
mirp[rp0,rnd,grey]  vheight_lo  13
mdrp[min,rnd,grey]  12
srp0    48
mirp[rp0,min,rnd,grey]  special_1 0
mirp[min,rnd,grey]  vstem 25
mdrp[min,rnd,grey]  36
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  headstem 42
IUP[y]
""",

    #thaidigit_two
    "uni0E52": """
SRP0    50
mirp[rp0,min,rnd,grey]  headhole    3
mirp[rp0,min,rnd,grey]  hstem   8
mdrp[rp0,min,rnd,grey]  30
mdrp[rnd,grey]  19
mdrp[min,rnd,grey]  47
mdrp[rp0,min,rnd,grey]  24
mirp[min,rnd,grey]  headstem 41
mdrp[rp0,min,rnd,grey]  13
mirp[rp0,min,rnd,grey]  hstem 36
mdrp[rnd,white]  51
srp1    3
srp2    8
sloop   4
ip  5 6 1 10
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem 11
mirp[rp0,rnd,grey]  vheight_num 32
alignrp 34
mirp[min,rnd,grey]  vstem_98 17
shp[rp2]    15
mdrp[rp0,min,rnd,grey]  33
mirp[rp0,min,rnd,grey]  vstem 16
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  headstem 44
mirp[rp0,rnd,grey]  headdia 27
mirp[min,rnd,grey]  headstem 38
srp0    0
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  5
IUP[y]
""",

    #thaidigit_three
    "uni0E53": """
SRP0    52
mirp[rp0,min,rnd,grey]  headhole    28
mirp[min,rnd,grey]  hstem   16
srp0    28
mdrp[min,rnd,grey]  49
mdrp[rp0,min,rnd,grey]  22
mirp[min,rnd,grey]  headstem 43
mdrp[rp0,rnd,grey]  10
mirp[rp0,min,rnd,grey]  hstem 9
mdrp[rp0,min,rnd,grey]  3
mirp[rp0,min,rnd,grey]  hstem 38
mdrp[rnd,white]  53
mdrp[rp0,rnd,grey]  0
mirp[min,rnd,grey]  hstem 1
srp1    10
srp2    9
ip  33
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 25
mirp[rp0,rnd,grey]  vheight_num 35
alignrp 31
mirp[min,rnd,grey]  vstem_98 6
shp[rp2]    13
mdrp[rp0,min,rnd,grey]  33
mdrp[min,rnd,grey]  10
srp0    25
mirp[min,rnd,grey]  headstem 40
mirp[rp0,rnd,grey]  headdia 19
mirp[min,rnd,grey]  headstem 46
mdrp[rnd,grey]  17
IUP[y]
""",

    #thaidigit_four
    "uni0E54": """
SRP0    51
mirp[rp0,min,rnd,grey]  headhole    7
mirp[rp0,min,rnd,grey]  hstem   20
mdrp[rp0,min,rnd,grey]  27
mdrp[min,rnd,grey]  25
mdrp[min,rnd,grey]  48
mdrp[rp0,rnd,grey]  33
mirp[min,rnd,grey]  headstem 42
mdrp[min,rnd,grey]  36
srp0    25
mdrp[rp0,min,rnd,grey]  2
mdrp[rp0,min,rnd,grey]  0
mdrp[rnd,grey]  14
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   51
mirp[rp0,rnd,grey]  special_2 0
alignrp 4
mdrp[rp0,min,rnd,grey]  38
mdrp[rp0,rnd,grey]  36
mdrp[min,rnd,grey]  39
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  headstem 45
srp0 4
mirp[rp0,min,rnd,grey]  vstem_98 23
mdrp[rnd,grey]  25
srp0    51
mirp[rp0,rnd,grey]  vheight_num 10
mirp[min,rnd,grey]  vstem_98 16
mdrp[rp0,rnd,grey]  13
mdrp[min,rnd,grey]  14
IUP[y]
""",

    #thaidigit_five
    "uni0E55": """
SRP0    73
mirp[rp0,min,rnd,grey]  headhole    7
mirp[rp0,min,rnd,grey]  hstem   30
mdrp[rp0,min,rnd,grey]  37
mdrp[min,rnd,grey]  35
mdrp[min,rnd,grey]  58
mdrp[rp0,rnd,grey]  43
mirp[min,rnd,grey]  headstem 52
mdrp[min,rnd,grey]  46
srp0    35
mdrp[rp0,min,rnd,grey]  2
mdrp[rp0,min,rnd,grey]  0
mdrp[rnd,grey]  24
srp0    7
mdrp[rp0,rnd,grey]  10
mdrp[rp0,rnd,grey]  12
mirp[min,rnd,grey]  headstem 70
mirp[rp0,rnd,grey]  headdia 18
mirp[min,rnd,grey]  headstem 64
mdrp[min,rnd,grey]  20
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   73
mirp[rp0,rnd,grey]  special_2 0
alignrp 4
mdrp[rp0,min,rnd,grey]  48
mdrp[rp0,rnd,grey]  46
mdrp[min,rnd,grey]  49
mdrp[rp0,rnd,grey]  40
mirp[min,rnd,grey]  headstem 55
srp0 4
mirp[rp0,min,rnd,grey]  vstem_98 33
mdrp[rnd,grey]  35
srp0    73
mirp[rp0,rnd,grey]  vheight_num 20
mirp[min,rnd,grey]  vstem_98 26
mdrp[rp0,rnd,grey]  23
mdrp[min,rnd,grey]  24
srp0    26
mdrp[min,rnd,grey]  61
mdrp[rp0,rnd,grey]  15
mirp[min,rnd,grey]  headstem    67
srp0    61
mdrp[rnd,grey]  10
IUP[y]
""",

    #thaidigit_six
    "uni0E56": """
SRP0    44
mirp[rp0,min,rnd,grey]  special_1 21
mdrp[min,rnd,grey]  22
mdrp[rp0,rnd,grey]  19
mirp[rp0,rnd,grey]  w_852   29
mirp[min,rnd,grey]  hstem   14
mdrp[rnd,white]  45
srp0    19
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  headstem 41
mirp[rp0,rnd,grey]  headdia 9
mirp[min,rnd,grey]  headstem 35
mdrp[rnd,grey]  11
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   44
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_num 26
mirp[min,rnd,grey]  vstem_98 17
mdrp[rp0,rnd,grey]  24
mdrp[min,rnd,grey]  19
mdrp[rp0,rnd,grey]  22
mdrp[min,rnd,grey]  21
srp0    0
mirp[min,rnd,grey]  vstem_98 11
mdrp[min,rnd,grey]  32
mdrp[rp0,rnd,grey]  6
mirp[min,rnd,grey]  headstem 38
IUP[y]
""",

    #thaidigit_seven
    "uni0E57": """
SRP0    61
mirp[rp0,min,rnd,grey]  headhole    28
mirp[min,rnd,grey]  hstem   16
mdrp[min,rnd,grey]  58
mdrp[rp0,rnd,grey]  22
mirp[min,rnd,grey]  headstem 52
mdrp[rp0,rnd,grey]  10
mirp[rp0,min,rnd,grey]  hstem 9
mdrp[rp0,min,rnd,grey]  3
mdrp[min,rnd,grey]  1
mirp[rp0,min,rnd,grey]  hstem 38
mdrp[rnd,grey]  40
mdrp[rp0,min,rnd,grey]  42
mirp[min,rnd,grey]  vstem_98 46
mdrp[min,rnd,grey]  44
mdrp[rnd,white]  62
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 25
mirp[rp0,rnd,grey]  vheight_num 35
alignrp 31
mirp[min,rnd,grey]  vstem_98 6
shp[rp2]    13
mdrp[rp0,min,rnd,grey]  33
mdrp[min,rnd,grey]  10
srp0    25
mirp[min,rnd,grey]  headstem 49
mirp[rp0,rnd,grey]  headdia 19
mirp[min,rnd,grey]  headstem 55
mdrp[rnd,grey]  17
srp0    1
mirp[rp0,min,rnd,grey]  vstem_98 40
mdrp[rp0,rnd,grey]  44
mdrp[min,rnd,grey]  45
IUP[y]
""",

    #thaidigit_eight
    "uni0E58": """
SRP0    52
mirp[rp0,min,rnd,grey]  headhole    6
mirp[rp0,min,rnd,grey]  hstem   19
mdrp[rp0,min,rnd,grey]  23
mdrp[rp0,min,rnd,grey]  24
mdrp[rp0,min,rnd,grey]  31
mdrp[min,rnd,grey]  28
mirp[min,rnd,grey]  headstem 49
mdrp[rp0,rnd,grey]  37
mdrp[min,rnd,grey]  43
mdrp[min,rnd,grey]  13
srp1    19
srp2    24
sloop   3
ip  22 3 2
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   52
mirp[rp0,rnd,grey]  special_2 3
alignrp 0
mdrp[min,rnd,grey]  22
mdrp[rp0,min,rnd,grey]  2
mdrp[min,rnd,grey]  23
mdrp[min,rnd,grey]  24
srp0    0
mirp[rp0,min,rnd,grey]  vstem_98 26
mdrp[rnd,grey]  28
srp0    0
mdrp[min,rnd,grey]  40
mdrp[rp0,rnd,grey]  34
mirp[min,rnd,grey]  headstem 46
srp0    0
mirp[rp0,rnd,grey]  vheight_num 9
mirp[min,rnd,grey]  vstem_98 15
mdrp[rp0,rnd,grey]  12
mdrp[min,rnd,grey]  13
IUP[y]
""",

    #thaidigit_nine
    "uni0E59": """
SRP0    59
mirp[rp0,min,rnd,grey]  headhole    26
mirp[rp0,min,rnd,grey]  hstem   9
mdrp[rp0,min,rnd,grey]  20
mdrp[rp0,min,rnd,grey]  3
mdrp[rp0,min,rnd,grey]  1
mirp[rp0,min,rnd,grey]  hstem 0
mdrp[rp0,rnd,grey]  41
mdrp[rp0,rnd,grey]  40
ip  35
mdrp[rp0,rnd,grey]  38
mdrp[min,rnd,grey]  37
alignrp 60
srp0    20
mirp[min,rnd,grey]  headstem 49
mirp[rp0,rnd,grey]  headdia 14
mirp[min,rnd,grey]  headstem 56
srp1    3
srp2    41
sloop   3
ip  31 45 35
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 23
mirp[rp0,rnd,grey]  vheight_num 33
alignrp 29
mirp[min,rnd,grey]  vstem_98 43
shp[rp2]    6
mdrp[rp0,rnd,grey]  31
alignrp 35
mdrp[min,rnd,grey]  45
srp0    35
mdrp[rp0,rnd,grey]  37
mdrp[min,rnd,grey]  38
srp0    23
mdrp[min,rnd,grey]  12
mdrp[min,rnd,grey]  47
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  headstem 53
IUP[y]
""",

#    #angkhankhu
    "uni0E5A": """
SRP0    35
mdrp[rp0,min,rnd,grey]  7
mirp[rp0,rnd,grey]  w_956 1
alignrp 17
mirp[rp0,min,rnd,grey]  hstem 18
mirp[rp0,rnd,grey]  headstem_tiny 20
mirp[rp0,min,rnd,grey]  hstem 22
mdrp[rnd,white]  36
srp0    7
mirp[min,rnd,grey]  headstem 32
mirp[rp0,rnd,grey]  headdia 13
mirp[min,rnd,grey]  headstem 26
mdrp[min,rnd,grey]  15
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 20
mirp[rp0,rnd,grey]  vheight_shoot 10
alignrp 17
mirp[min,rnd,grey]  headstem 29
mdrp[rp0,rnd,grey]  4
mdrp[min,rnd,grey]  23
mdrp[min,rnd,grey]  15
mdrp[min,rnd,grey]  2
srp1    17
sloop 3
ip 18 21 22
IUP[y]
""",

#    #khomut
    "uni0E5B": """
SRP0    70
mirp[rp0,min,rnd,grey]  headhole    3
mirp[rp0,min,rnd,grey]  hstem   26
mdrp[rp0,min,rnd,grey]  15
mirp[min,rnd,grey]  headstem   67
mdrp[rp0,min,rnd,grey]  9
mdrp[min,rnd,grey]  61
mdrp[min,rnd,grey]  20
mdrp[rp0,min,rnd,grey]  32
mdrp[min,rnd,grey]  33
mdrp[rp0,min,rnd,grey]  55
mdrp[min,rnd,grey]  54
mdrp[rp0,min,rnd,grey]  34
mdrp[rp0,min,rnd,grey]  37
mdrp[min,rnd,grey]  38
mdrp[rp0,min,rnd,grey]  52
mdrp[min,rnd,grey]  51
mdrp[rp0,min,rnd,grey]  39
mdrp[rp0,min,rnd,grey]  42
mdrp[min,rnd,grey]  43
mdrp[rp0,min,rnd,grey]  49
mdrp[rp0,min,rnd,grey]  46
mdrp[min,rnd,grey]  71
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   70
mirp[rp0,rnd,grey]  vheight_lo  0
mirp[rp0,min,rnd,grey]  vstem_98 29
mdrp[rp0,min,rnd,grey]  12
mirp[min,rnd,grey]  headstem 58
mirp[rp0,rnd,grey]  headdia 18
mdrp[min,rnd,grey]  20
mirp[min,rnd,grey]  headstem 64
mdrp[rp0,min,rnd,grey]  23
mirp[min,rnd,grey]  vstem_98 6
srp0    0
mdrp[rp0,min,rnd,grey]  55
alignrp     52
alignrp     49
alignrp     45
mdrp[min,rnd,grey]  54
shp[rp2]    51
mdrp[rp0,min,rnd,grey]  32
alignrp 37
alignrp 42
mdrp[rp0,min,rnd,grey]  33
alignrp 38
alignrp 43
srp0    45
mdrp[min,rnd,grey]  46
IUP[y]
""",


#    #CHAR_NAME
#    "uni0EXX": """
#SRP0    0
#
#IUP[x]
#SVTCA[y-axis]
#MDAP[rnd]   0
#
#IUP[y]
#""",


}

if __name__=="__main__":
    if sys.argv[1] == "--all":
        #$0 --all = ENCODE ALL CHARS
        sfd_file = os.path.basename(sys.argv[0]).split('.',1)[0] + '.sfd'
        print "Encoding all character in %s" % (sfd_file)
        dfont.inst_encode_all( sfd_file, pseudo_code_dict, cvt_dict )
    else:
        #$0 uni0E01 > x.txt = PRINT INSTRUCTION CODE OF uni0E01 TO x.txt
        print '\n'.join(dfont.inst_encode( pseudo_code_dict[sys.argv[1]], cvt_dict ))
